# RST Conventions

It's a Markdown world!

This document outlines RST conventions that may be helpful in editing this documentation.

## Headings

RST assigns heading levels in the order it encounters them during processing.
We use the following mappings:

```
H1 = with overline, for parts
H2 * with overline, for chapters
H3 -, for sections
H4 ~, for subsections
H5 ^, for subsubsections
H6 “, for paragraphs
```


